<template>
	<NodeBasicLayout v-model:title="data.title" :type="NodeType.Code" :showOffset="false" :description="data.description">
		<Handle :id="targetHandleId" type="target" :position="Position.Left" />
		<FieldLayout :title="codeInput.name">
			<el-input  class="w-full flex-0" v-model="codeInput.params[0].value" placeholder="参数名"> </el-input>

		</FieldLayout>
		<FieldLayout :title="codeStr.name">
			<div class="relative">
				<codemirror
					@scroll="handleCodeScroll"
					class="nowheel overflow-auto [&>.cm-editor]:min-h-[140px] [&>.cm-editor]:max-h-[340px] cursor-text"
					v-model="codeStr.params[0].value"
					:autofocus="true"
					:indent-with-tab="true"
					:tab-size="2"
					:extensions="javascriptEditorExtensions"
				/>
				<!-- <el-tooltip effect="dark" content="全屏" placement="top">
				
				</el-tooltip> -->
				<YWIcon
					class="absolute right-1 top-1 !text-gray-300 cursor-pointer"
					name="pingmufangda"
					@click="fullEditCodeClick(codeStr.params[0])"
				/>
			</div>
		</FieldLayout>
		
		<Handle :id="sourceHandleId" type="source" :position="Position.Right" />
		<Teleport to="body">
			<CodeEditDialog v-if="editMapCodeItem" v-model="codeEditDlgIsShow" :item="editMapCodeItem"></CodeEditDialog>
		</Teleport>
	</NodeBasicLayout>
</template>

<script lang="ts" setup>
import { javascript } from '@codemirror/lang-javascript';
import { vscodeDark } from '@uiw/codemirror-theme-vscode';
import type { NodeProps } from '@vue-flow/core';
import { Handle, Position, useNode } from '@vue-flow/core';
import { ref } from 'vue';
import { Codemirror } from 'vue-codemirror';
import { VueFlowHelper } from '../../VueFlowHelper';
import { NodeType, ParameterType, parameterTypeMap } from '../../vueFlowEnum';
import CodeEditDialog from './components/CodeEditDlg.vue';
import FieldLayout from './components/FieldLayout.vue';
import NodeBasicLayout from './components/NodeBasicLayout.vue';
import type { LLMNodeData, LLMNodeEvents } from './index';
defineProps<NodeProps<LLMNodeData, LLMNodeEvents>>();
const node = useNode();
const targetHandleId = ref(VueFlowHelper.getHandleId(node.node, 'target'));
const sourceHandleId = ref(VueFlowHelper.getHandleId(node.node, 'source'));

const javascriptEditorExtensions = [javascript(), vscodeDark];

const data = ref(node.node.data);
const codeInput = ref(VueFlowHelper.getGroupParam(data.value, 0));
const codeStr = ref(VueFlowHelper.getGroupParam(data.value, 1));
const handleCodeScroll = (e) => {
	e.stopPropagation();
};
const getInputEmptyItem = () => {
	return {
		key: '',
		type: 'input',
		label: '',
		value: '',
	};
};

const getOutputEmptyItem = () => {
	return {
		key: '',
		type: ParameterType.String,
	};
};
const delInputVarItem = (index) => {
	if (!codeInput.value.params[0].value || codeInput.value.params[0].value.length === 0) {
		return;
	}
	// if (codeInput.value.params[0].value?.length === 1) {
	// 	codeInput.value.params[0].value = getEmptyItem();
	// 	return;
	// }
	codeInput.value.params[0].value.splice(index, 1);
};

const addInputVarItem = () => {
	if (!codeInput.value.params[0].value || codeInput.value.params[0].value.length === 0) {
		codeInput.value.params[0].value = [];
	}
	codeInput.value.params[0].value.push(getInputEmptyItem());
};




const editMapCodeItem = ref({});
const codeEditDlgIsShow = ref(false);
const fullEditCodeClick = (item) => {
	editMapCodeItem.value = item;
	codeEditDlgIsShow.value = true;
};
</script>
